import numpy as np
import matplotlib.pyplot as plt

def create_subplots(rows, cols, functions, x_values=None, labels=None, colors=None):
  """
  Automatically creates subplots based on the number of rows, columns, 
  and the provided list of functions.
  
  Parameters:
      - rows: number of rows in the subplot grid
      - cols: number of columns in the subplot grid
      - functions: list of functions to plot on subplots
      - x_values: x data for plotting (default is np.linspace(0, 2*np.pi, 100))
      - labels: list of labels for the y-axis of each subplot
      - colors: list of colors for each plot
  """

  if x_values is None:
    x_values = np.linspace(0, 2 * np.pi, 100)

  fig, axs = plt.subplots(rows, cols, figsize=(18, 5), sharex=True)
  axs = axs.flatten()

  for i, func in enumerate(functions):
    axs[i].plot(x_values, func(x_values), label=f'{labels[i]}' if labels else f'Function {i+1}', color=colors[i] if colors else 'b')
    axs[i].set_xlabel('x')
    axs[i].set_ylabel(labels[i] if labels else f'Function {i+1}')
    axs[i].legend()

  plt.tight_layout()
  plt.show()